import { Project } from "../generated/graphql";
import React, { FC, Fragment } from "react";
import { IconButton, Grid, Paper, Portal, Typography, Box } from "@mui/material";
import makeStyles from '@mui/styles/makeStyles';
import { useHeaderContainer } from "../layouts";
import { PipelineList } from "../pipelines/pipeline-list";
import { Edit } from '@mui/icons-material';
import { Link } from '@curi/react-dom';
import { Button } from "@mui/material";
import { AddBox } from "@mui/icons-material";

interface Props {
  project: Project;
}

const useStyles = makeStyles(() => ({
  root: {
    height: "100%",
    flex: "auto",
    overflow: "hidden"
  },
  pipelineListContainer: {
    height: "100%",
    width: "100%",
    overflow: "auto"
  },
}));

export const ProjectDetail: FC<Props> = ({ project, children }) => {
  const headerContainer = useHeaderContainer();

  const classes = useStyles();

  return (
    <Fragment>
      <Portal container={headerContainer}>
        <Grid
          container
          spacing={3}
          direction="row"
          justifyContent="space-between"
          alignItems="center"
        >
          <Grid item>
            <Typography component="h1" variant="h6" noWrap>
              {project.name}
            </Typography>
            <Typography variant="subtitle2" gutterBottom noWrap>
              {project.comment}
            </Typography>
          </Grid>
          <Grid item>
            <Link name="edit-project" params={{ projectId: project.id }}>
              <IconButton color="inherit" size="large">{<Edit />}</IconButton>
            </Link>
          </Grid>
        </Grid>
      </Portal>
      <Grid
        container
        spacing={0}
        direction="row"
        alignItems="stretch"
        className={classes.root}
      >
        <Grid item xs={3} lg={2} style={{ height: "100%", display: "flex" }}>
          <Paper className={classes.pipelineListContainer}>
            <Box m={2}>
              <Link name="create-pipeline" params={{ projectId: project.id }}>
                <Button
                  variant="contained"
                  color="primary"
                  title="New Pipeline"
                  startIcon={<AddBox />}
                >
                  New Pipeline
                </Button>
              </Link>
            </Box>
            <PipelineList projectId={project.id} />
          </Paper>
        </Grid>
        <Grid
          item
          xs={9}
          lg={10}
          style={{ height: "100%", display: "flex", overflowY: "auto" }}
        >
          {children}
        </Grid>
      </Grid>
    </Fragment>
  );
};
